ewa.rules.MatchRule

Package ewa :: Module rules :: Class MatchRule |
[hide private]
[frames] | no frames]

# Class MatchRule

source code

    object --+
             |
     _jsonable --+
                 |
                MatchRule

Instance Methods | [hide private]
__init__(self, matcher, pre=None, post=None) the matcher is a callable with a "match" method. | source code
_gen_list(self, filename, match) | source code
_match(self, filename) | source code
__call__(self, filename) | source code
Inherited from `_jsonable`: `to_jsondata` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, matcher, pre=None, post=None) (Constructor) | source code
the matcher is a callable with a "match" method. pre and post and lists of things that go before and after the filename passed in. Overrides: object.__init__